@@ -424,6 +424,7 @@ tl_set_size (Control *control, int size)
 gboolean
 create_tl_control (Control * control)
 {
+	GtkWidget *alignment;
 	t_tl *tl = NULL;
 	
 	if (!tooltips) {
@@ -431,7 +432,12 @@ create_tl_control (Control * control)
 	}
 	
 	tl = tl_new ();
-	gtk_container_add (GTK_CONTAINER (control->base), GTK_WIDGET(tl->hbox));
+	
+	alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	gtk_container_add (GTK_CONTAINER (alignment), GTK_WIDGET(tl->hbox));
+	gtk_widget_show (alignment);
+
+	gtk_container_add (GTK_CONTAINER (control->base), alignment);
 
 	control->data = (gpointer) tl;
 	control->with_popup = FALSE;
@@ -1086,7 +1092,7 @@ xfce_control_class_init (ControlClass * cc)
     textdomain (GETTEXT_PACKAGE);
 #endif
 
-    cc->name = "tl";
+    cc->name = "triggerlauncher";
     cc->caption = _("Two-state Launcher");
 
     cc->create_control = (CreateControlFunc) create_tl_control;
